@@ -7,16 +7,16 @@ package Vote::Count::RankCount;
 use feature qw /postderef signatures/;
 no warnings 'experimental';
 use List::Util qw( min max sum);
-use Vote::Count::TextTableTiny qw/generate_markdown_table/;
+use Vote::Count::TextTableTiny qw/generate_table/;
 use Sort::Hash;
 
-our $VERSION='1.09';
+our $VERSION='1.10';
 
 =head1 NAME
 
 Vote::Count::RankCount
 
-=head1 VERSION 1.09
+=head1 VERSION 1.10
 
 =cut
 
@@ -44,6 +44,7 @@ sub _RankResult ( $rawcount ) {
         }
       }
     }
+    # uncoverable branch true
     die "Vote::Count::RankCount::Rank in infinite loop\n"
       if $pos > $maxpos;
   }
@@ -74,6 +75,14 @@ sub _RankResult ( $rawcount ) {
 
 Takes a single argument of a hashref containing Choices as Keys and Votes as Values. Returns an Object. This method is also aliased as new.
 
+=head1 newFromList
+
+Takes an ordered list and returns a RankCount Object where the RawCount values are the position time -1: Item 3 in the list will have -3 votes while Item 1 have -1.
+
+  my $ordered_rank_count = Vote::Count::RankCount->newFromList( @ordered_list );
+
+
+
 =cut
 
 sub Rank ( $class, $rawcount ) {
@@ -86,6 +95,15 @@ sub new ( $class, $rawcount ) {
   return bless $I, $class;
 }
 
+sub newFromList ( @list ) {
+  shift @list;
+  my $pos = 0;
+  my $newobj = Vote::Count::RankCount->Rank({
+    map { $_ => --$pos } @list} );
+  $newobj->{'orderedlist'} = \@list;
+  return $newobj;
+}
+
 =head2 Methods
 
 =over
@@ -96,7 +114,7 @@ Returns the original HashRef used for Object Creation.
 
 =item * HashWithOrder
 
-Returns a HashRef with the Choices as Keys and the position of the choice, the value for the Leader would be 1 and the Third Place Choice would be 3.
+Returns a HashRef with the Choices as Keys and the position of the choice, the value for the Leader would be 1 and the Third Place Choice would be 3. If choices are tied they will share the same value for their position.
 
 =item * HashByRank
 
@@ -106,6 +124,10 @@ Returns a HashRef where the keys are numbers and the values an ArrayRef of the C
 
 Returns an ArrayRef of the Choices in the Top or Bottom Positions.
 
+=item * OrderedList
+
+Returns the array that was to create the RankCount object if it was created from a List. Returns an exception if the object was created from a HashRef, because RankCount does not deal with ties. Returning a list with ties resolved by randomness or a sort would not be correct.
+
 =item * CountVotes
 
 Returns the number of votes in the RawCount. This is not the same as the votes in the BallotSet from which that was derived. For TopCount it is the number of non-exhausted ballots in the round that generated RawCount, for Approval and Boorda it is probably not useful.
@@ -120,6 +142,10 @@ Returns a HashRef with the keys tie, tied, winner where winner is the winner, ti
 
 Generates a MarkDown formatted table.
 
+=head3 RankTableWeighted ($votevalue)
+
+Ranktable for use with weighted votes. Displays both the Vote Value and the Vote Total (rounded to two places). Requires Vote Value as an argument.
+
 =cut
 
 sub RawCount ( $I )      { return $I->{'rawcount'} }
@@ -129,6 +155,11 @@ sub ArrayTop ( $I )      { return $I->{'top'} }
 sub ArrayBottom ( $I )   { return $I->{'bottom'} }
 sub CountVotes ($I)      { return sum( values $I->{'rawcount'}->%* ) }
 
+sub OrderedList ($I)     {
+  return $I->{'orderedlist'}->@* if defined $I->{'orderedlist'};
+  die "OrderedList may only be used if the RankCount object was created from an ordered list.\n";
+  }
+
 sub Leader ( $I ) {
   my @leaders = $I->ArrayTop()->@*;
   my %return = ( 'tie' => 0, 'winner' => '', 'tied' => [] );
@@ -150,9 +181,27 @@ sub RankTable( $self ) {
       push @rows, ( \@row );
     }
   }
-  return generate_markdown_table( rows => \@rows ) . "\n";
+  return generate_table( rows => \@rows, style => 'markdown' ) . "\n";
 }
 
+sub RankTableWeighted( $self, $votevalue ) {
+  my @rows   = ( [ 'Rank', 'Choice', 'Votes', 'VoteValue' ] );
+  my %rc     = $self->{'rawcount'}->%*;
+  my %byrank = $self->{'byrank'}->%*;
+  for my $r ( sort { $a <=> $b } ( keys %byrank ) ) {
+    my @choice = sort $byrank{$r}->@*;
+    for my $choice (@choice) {
+      my $votes = $rc{$choice};
+      my @row = ( $r, $choice, sprintf("%.2f", $votes/$votevalue), $votes );
+      push @rows, ( \@row );
+    }
+  }
+  return generate_table(
+    rows => \@rows,
+    style => 'markdown',
+    align => [qw/ l l r r /]
+    ) . "\n";
+}
 1;
 
 #FOOTER
